/*
 * Copyright (c) 2018-2023 Red Hat, Inc.
 * This program and the accompanying materials are made
 * available under the terms of the Eclipse Public License 2.0
 * which is available at https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *   Red Hat, Inc. - initial API and implementation
 */

import { V1alpha2DevWorkspaceSpec } from '@devfile/api';

import { DevWorkspaceSpecTemplate } from '@/services/devfileApi/devWorkspace/spec/template';

export type DevWorkspaceSpec = V1alpha2DevWorkspaceSpec & {
  template: DevWorkspaceSpecTemplate;
};
